@@ -3,8 +3,8 @@
 # 【動作確認 / 使用例】
 
 import sys
-from relpath import rel2abs
-sys.path.append(rel2abs("../"))
+from relpath import add_import_path
+add_import_path("../")
 # 巨大オブジェクトのデバッグ表示 [sout]
 from sout import sout
 
